aboutsummaryrefslogtreecommitdiffstats
path: root/python/wpt/exporter/github.py
diff options
context:
space:
mode:
Diffstat (limited to 'python/wpt/exporter/github.py')
-rw-r--r--python/wpt/exporter/github.py4
1 files changed, 2 insertions, 2 deletions
diff --git a/python/wpt/exporter/github.py b/python/wpt/exporter/github.py
index 31fa5bb93c3..08b491765be 100644
--- a/python/wpt/exporter/github.py
+++ b/python/wpt/exporter/github.py
@@ -74,7 +74,7 @@ class GithubRepository:
self, branch: GithubBranch
) -> Optional[PullRequest]:
"""If this repository has an open pull request with the
given source head reference targeting the master branch,
return the first matching pull request, otherwise return None."""
params = "+".join([
@@ -105,7 +105,7 @@ class GithubRepository:
data = {
"title": title,
"head": branch.get_pr_head_reference_for_repo(self),
- "base": "master",
+ "base": "main",
"body": body,
"maintainer_can_modify": False,
}
@@ -74,7 +74,7 @@ class GithubRepository:
) -> Optional[PullRequest]:
"""If this repository has an open pull request with the
- given source head reference targeting the master branch,
+ given source head reference targeting the main branch,
return the first matching pull request, otherwise return None."""
params = "+".join([